import { default as WJElement } from '../wje-element/element.js';
/**
 * @summary This class represents a Breadcrumb element, extending the WJElement class. It provides a navigational aid in user interfaces, displaying the current location within a hierarchy.
 * @documentation https://elements.webjet.sk/components/breadcrumb
 * @status stable
 * @augments WJElement
 * @slot - The main content of the breadcrumb.
 * @slot start - Slot for content at the start of the breadcrumb.
 * @slot end - Slot for content at the end of the breadcrumb.
 * @slot separator - Slot for a custom separator between breadcrumb items.
 * @csspart native - The native wrapper of the breadcrumb component.
 * @csspart separator - The separator between breadcrumb items.
 * @cssproperty [--wje-breadcrumb-a=var(--wje-color-contrast-8)] - The color of the breadcrumb text.
 * @cssproperty [--wje-breadcrumb-a-hover=var(--wje-color-contrast-6)] - The color of the breadcrumb separator line.
 * @tag wje-breadcrumb
 */
export default class Breadcrumb extends WJElement {
    /**
     * Get CSS stylesheet for the Breadcrumb element.
     * @static
     * @returns {object} styles - The CSS styles
     */
    static get cssStyleSheet(): object;
    /**
     * Get observed attributes for the Breadcrumb element.
     * @static
     * @returns {Array<string>} - The observed attributes array for the Breadcrumb element.
     */
    static get observedAttributes(): Array<string>;
    _showSeparator: boolean;
    showCollapsedIndicator: boolean;
    /**
     * Set show separator flag.
     * @param {boolean} value The value to set
     */
    set showSeparator(value: boolean);
    /**
     * Get show separator flag.
     * @returns {boolean} showSeparator - The show separator flag
     */
    get showSeparator(): boolean;
    /**
     * Set collapsed variant.
     * @param {string} value The value to set
     */
    set collapsedVariant(value: string);
    /**
     * Get collapsed variant.
     * @returns {string} The collapsed variant value in uppercase.
     */
    get collapsedVariant(): string;
    _collapsedVariant: string;
    /**
     * Attribute changed callback method.
     * @returns {boolean} false - Always returns false
     */
    attributeChangedCallback(name: any, oldValue: any, newValue: any): boolean;
    active: boolean;
    /**
     * Draw method for the Breadcrumb element.
     * @returns {object} fragment - The document fragment
     */
    draw(): object;
    native: HTMLAnchorElement;
    /**
     * Draw collapsed indicator method.
     * @returns {object} - The collapsed indicator element.
     */
    drawCollapsedIndicator(): object;
    /**
     * Collapse dropdown button.
     * @returns {object} dropdown - The dropdown button.
     */
    collapseDropdown(): object;
    /**
     * Collapse button method.
     * @returns {object} - The button element.
     */
    collapseButton(): object;
}
