import { default as WJElement } from '../wje-element/element.js';
/**
 * `QrCode` is a custom web component that generates a QR code.
 * @summary This element represents a QR code generator.
 * @documentation https://elements.webjet.sk/components/qr-code
 * @status stable
 * @augments {WJElement}
 * @csspart native - The native part of the QR code.
 * @slot top - The slot for the top content of the QR code.
 * @slot bottom - The slot for the bottom content of the QR code.
 * @tag wje-qr-code
 */
export default class QrCode extends WJElement {
    /**
     * Returns the CSS stylesheet for the component.
     * @returns {CSSStyleSheet} The CSS stylesheet.
     */
    static get cssStyleSheet(): CSSStyleSheet;
    /**
     * Returns the list of observed attributes.
     * @returns {string[]} The list of observed attributes.
     */
    static get observedAttributes(): string[];
    /**
     * Draws the QR code component.
     * @returns {DocumentFragment} The document fragment containing the QR code component.
     */
    draw(): DocumentFragment;
    /**
     * Called after the component is drawn to generate the QR code.
     */
    afterDraw(): void;
}
